View source: R/903_post_hoc_fns.R
| BTRR_extract_B | R Documentation |
As the BTRR_single_subject function saves posterior samples of the
tensor decomposition components, the tensor coefficient is composed from
results of class BTRR_result.
BTRR_extract_B(btrr_result)
btrr_result |
A list object with class |
An array in which the last index corresponds to the ith draw
from the posterior distribution.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.